@@ -6,8 +6,6 @@ module Octokit
     # @see https://developer.github.com/v3/orgs/
     module Organizations
 
-      ORG_INVITATIONS_PREVIEW_MEDIA_TYPE = "application/vnd.github.the-wasp-preview+json".freeze
-
       # Get an organization
       #
       # @param org [String, Integer] Organization GitHub login or id.
@@ -306,8 +304,9 @@ module Octokit
       #   @client.add_team_member(100000, 'pengwynn')
       #
       # @example
-      #   # Invite a member to a team. The user won't be added to the 
-      #   # team until he/she accepts the invite via email.
+      #   # Opt-in to future behavior for this endpoint. Adds the member to the
+      #   # team if they're already an org member. If not, the method will return
+      #   # 422 and indicate the user should call the new Team Membership endpoint.
       #   @client.add_team_member \
       #     100000,
       #     'pengwynn',
@@ -496,13 +495,11 @@ module Octokit
       #
       # @example Check if a user has a membership for a team
       #   @client.team_membership(1234, 'pengwynn')
-      #   => false
       def team_membership(team_id, user, options = {})
-        options = ensure_org_invitations_api_media_type(options)
         get "teams/#{team_id}/memberships/#{user}", options
       end
 
-      # Invite a user to a team
+      # Add or invite a user to a team
       #
       # @param team_id [Integer] Team id.
       # @param user [String] GitHub username of the user to invite.
@@ -513,9 +510,7 @@ module Octokit
       #
       # @example Check if a user has a membership for a team
       #   @client.add_team_membership(1234, 'pengwynn')
-      #   => false
       def add_team_membership(team_id, user, options = {})
-        options = ensure_org_invitations_api_media_type(options)
         put "teams/#{team_id}/memberships/#{user}", options
       end
 
@@ -528,28 +523,38 @@ module Octokit
       # @example
       #   @client.remove_team_membership(100000, 'pengwynn')
       def remove_team_membership(team_id, user, options = {})
-        options = ensure_org_invitations_api_media_type(options)
         boolean_from_response :delete, "teams/#{team_id}/memberships/#{user}", options
       end
 
-      private
-
-      def ensure_org_invitations_api_media_type(options = {})
-        if options[:accept].nil?
-          options[:accept] = ORG_INVITATIONS_PREVIEW_MEDIA_TYPE
-          warn_org_invitations_preview
-        end
-
-        options
+      # List all organizations memberships for the authenticated user
+      #
+      # @return [Array<Sawyer::Resource>] Array of organizations memberships.
+      # @see https://developer.github.com/v3/orgs/members/#list-your-organization-memberships
+      def organization_memberships(options = {})
+        paginate "user/memberships/orgs", options
       end
+      alias :org_memberships :organization_memberships
 
-      def warn_org_invitations_preview
-        octokit_warn \
-          "WARNING: The preview version of the Organization Team Memberships API " \
-          "is not yet suitable for production use. You can avoid this message by " \
-          "supplying an appropriate media type in the 'Accept' request header. " \
-          "See the blog post for details: http://git.io/a9jglQ"
+      # Get an organization membership for the authenticated user
+      #
+      # @param org [String] Organization GitHub login.
+      # @return [Sawyer::Resource] Hash representing the organization membership.
+      # @see https://developer.github.com/v3/orgs/members/#get-your-organization-membership
+      def organization_membership(org, options = {})
+        get "user/memberships/orgs/#{org}", options
       end
+      alias :org_membership :organization_membership
+
+      # Edit an organization membership for the authenticated user
+      #
+      # @param org [String] Organization GitHub login.
+      # @option options [String] :state The state that the membership should be in.
+      # @return [Sawyer::Resource] Hash representing the updated organization membership.
+      # @see https://developer.github.com/v3/orgs/members/#edit-your-organization-membership
+      def update_organization_membership(org, options = {})
+        patch "user/memberships/orgs/#{org}", options
+      end
+      alias :update_org_membership :update_organization_membership
     end
   end
 end
