@@ -54,15 +54,18 @@ module Octokit
       #                      a merge to a base of another repo.
       # @param head [String] The branch (or git ref) where your changes are implemented.
       # @param title [String] Title for the pull request
-      # @param body [String] The body for the pull request. Supports GFM.
+      # @param body [String] The body for the pull request (optional). Supports GFM.
       # @return [Sawyer::Resource] The newly created pull request
-      def create_pull_request(repo, base, head, title, body, options = {})
+      # @example
+      #   @client.create_pull_request("octokit/octokit.rb", "master", "feature-branch",
+      #     "Pull Request title", "Pull Request body")
+      def create_pull_request(repo, base, head, title, body = nil, options = {})
         pull = {
           :base  => base,
           :head  => head,
           :title => title,
-          :body  => body,
         }
+        pull[:body] = body unless body.nil?
         post "#{Repository.path repo}/pulls", options.merge(pull)
       end
 
@@ -165,7 +168,7 @@ module Octokit
       #     :since => '2010-05-04T23:45:02Z'
       #   })
       def pull_requests_comments(repo, options = {})
-        get("#{Repository.path repo}/pulls/comments", options)
+        paginate("#{Repository.path repo}/pulls/comments", options)
       end
       alias :pulls_comments   :pull_requests_comments
       alias :reviews_comments :pull_requests_comments
@@ -178,7 +181,7 @@ module Octokit
       # @return [Array<Sawyer::Resource>] List of comments
       def pull_request_comments(repo, number, options = {})
         # return the comments for a pull request
-        get "#{Repository.path repo}/pulls/#{number}/comments", options
+        paginate("#{Repository.path repo}/pulls/#{number}/comments", options)
       end
       alias :pull_comments   :pull_request_comments
       alias :review_comments :pull_request_comments
