@@ -23,8 +23,8 @@ module Octokit
       # @option options [String] :target_commitish Specifies the commitish value that determines where the Git tag is created from.
       # @option options [String] :name Name for the release
       # @option options [String] :body Content for release notes
-      # @option options [String] :draft Mark this release as a draft
-      # @option options [String] :prerelease Mark this release as a pre-release
+      # @option options [Boolean] :draft Mark this release as a draft
+      # @option options [Boolean] :prerelease Mark this release as a pre-release
       # @return [Sawyer::Resource] The release
       # @see https://developer.github.com/v3/repos/releases/#create-a-release
       def create_release(repo, tag_name, options = {})
@@ -47,8 +47,8 @@ module Octokit
       # @option options [String] :target_commitish Specifies the commitish value that determines where the Git tag is created from.
       # @option options [String] :name Name for the release
       # @option options [String] :body Content for release notes
-      # @option options [String] :draft Mark this release as a draft
-      # @option options [String] :prerelease Mark this release as a pre-release
+      # @option options [Boolean] :draft Mark this release as a draft
+      # @option options [Boolean] :prerelease Mark this release as a pre-release
       # @return [Sawyer::Resource] The release
       # @see https://developer.github.com/v3/repos/releases/#edit-a-release
       def update_release(url, options = {})
@@ -127,6 +127,23 @@ module Octokit
         boolean_from_response(:delete, asset_url, options)
       end
 
+      # Get the release for a given tag
+      #
+      # @param repo [Integer, String, Repository, Hash] A GitHub repository
+      # @param tag_name [String] the name for a tag
+      # @return [Sawyer::Resource] The release
+      def release_for_tag(repo, tag_name, options = {})
+        get "#{Repository.path repo}/releases/tags/#{tag_name}", options
+      end
+
+      # Get the latest release
+      #
+      # @param repo [Integer, String, Repository, Hash] A GitHub repository
+      # @return [Sawyer::Resource] The release
+      def latest_release(repo, options = {})
+        get "#{Repository.path repo}/releases/latest", options
+      end
+
       private
 
       def content_type_from_file(file)
